==> plasma-widget-menubar_0.1.13.orig.tar.bz2: plasma-widget-menubar-0.1.13/src/menuwidget.h <==
/*
 * Plasma applet to display application window menus
 *
 * Copyright 2010 Canonical Ltd.
 *
 * Authors:
 * - Aurélien Gâteau <aurelien.gateau@canonical.com>
 *
 * License: GPL v3
 */
#ifndef MENUWIDGET_H
#define MENUWIDGET_H

// Qt
#include <QFontMetrics>
#include <QGraphicsSceneMouseEvent>
#include <QToolButton>

// KDE
#include <Plasma/Applet>
#include <Plasma/ToolButton>

class QGraphicsLinearLayout;
class QMenu;

class MenuButton : public Plasma::ToolButton
{
    Q_OBJECT
public:
    MenuButton(QGraphicsWidget* parent, QMenu* menu)
    : Plasma::ToolButton(parent)
    , mMenu(menu)
    {}

    QMenu* menu() const { return mMenu; }

    QSizeF sizeHint(Qt::SizeHint which, const QSizeF& constraint) const
    {
        QSizeF sh = Plasma::ToolButton::sizeHint(which, constraint);
        if (which == Qt::MinimumSize || which == Qt::PreferredSize) {
            sh.setHeight(nativeWidget()->fontMetrics().height());
        }
        return sh;
    }

protected:
    // Let the event propagate so that the applet context menu is shown
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
    {
        event->ignore();
    }

private:
    QMenu* mMenu;
};


class MenuWidget : public QGraphicsWidget
{
    Q_OBJECT
public:
    MenuWidget(Plasma::Applet* applet);
    void setMenu(QMenu*);
    void activate();
    void activateAction(QAction*);
    void activateActionInMenu(QAction* action);

protected:
    virtual bool eventFilter(QObject*, QEvent*);

private Q_SLOTS:
    void slotButtonClicked();
    void showMenu(MenuButton*);
    void checkMousePosition();
    void slotAboutToHideMenu();
    void createButtons();

private:
    Plasma::Applet* mApplet;
    QGraphicsLinearLayout* mLayout;
    QTimer* mMouseChecker;
    QTimer* mCreateButtonsTimer;
    QMenu* mRootMenu;
    QList<MenuButton*> mMenuButtonList;
    MenuButton* mCurrentButton;

    void showNextPrevMenu(bool next);
    void createButton(const QString& text, QMenu*);

    bool rootMenuEventFilter(QEvent*);
    bool subMenuEventFilter(QMenu*, QEvent*);
};
#endif /* MENUWIDGET_H */

==> plasma-widget-menubar_0.1.15.orig.tar.bz2: plasma-widget-menubar-0.1.15/src/menuwidget.h <==
/*
 * Plasma applet to display application window menus
 *
 * Copyright 2010 Canonical Ltd.
 *
 * Authors:
 * - Aurélien Gâteau <aurelien.gateau@canonical.com>
 *
 * License: GPL v3
 */
#ifndef MENUWIDGET_H
#define MENUWIDGET_H

// Qt
#include <QFontMetrics>
#include <QGraphicsSceneMouseEvent>
#include <QToolButton>

// KDE
#include <Plasma/Applet>
#include <Plasma/ToolButton>

class QGraphicsLinearLayout;
class QMenu;

class MenuButton : public Plasma::ToolButton
{
    Q_OBJECT
public:
    MenuButton(QGraphicsWidget* parent)
    : Plasma::ToolButton(parent)
    , mMenu(0)
    {}

    void setMenu(QMenu* menu) { mMenu = menu; }

    QMenu* menu() const { return mMenu; }

    QSizeF sizeHint(Qt::SizeHint which, const QSizeF& constraint) const
    {
        QSizeF sh = Plasma::ToolButton::sizeHint(which, constraint);
        if (which == Qt::MinimumSize || which == Qt::PreferredSize) {
            sh.setHeight(nativeWidget()->fontMetrics().height());
        }
        return sh;
    }

protected:
    // Let the event propagate so that the applet context menu is shown
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
    {
        event->ignore();
    }

private:
    QMenu* mMenu;
};


class MenuWidget : public QGraphicsWidget
{
    Q_OBJECT
public:
    MenuWidget(Plasma::Applet* applet);
    void setMenu(QMenu*);
    void activate();
    void activateAction(QAction*);
    void activateActionInMenu(QAction* action);

protected:
    virtual bool eventFilter(QObject*, QEvent*);

private Q_SLOTS:
    void slotButtonClicked();
    void showMenu(MenuButton*);
    void checkMousePosition();
    void slotAboutToHideMenu();
    void updateButtons();

private:
    Plasma::Applet* mApplet;
    QGraphicsLinearLayout* mLayout;
    QTimer* mMouseChecker;
    QTimer* mUpdateButtonsTimer;
    QMenu* mRootMenu;
    QList<MenuButton*> mMenuButtonList;
    MenuButton* mCurrentButton;

    void showNextPrevMenu(bool next);
    MenuButton* createButton();

    bool rootMenuEventFilter(QEvent*);
    bool subMenuEventFilter(QMenu*, QEvent*);
};
#endif /* MENUWIDGET_H */
